==> broadleaf-common-2.4.0-GA-sources.jar: org/broadleafcommerce/common/site/service/type/SiteResolutionType.java <==
/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.broadleafcommerce.common.site.service.type;

import org.broadleafcommerce.common.BroadleafEnumerationType;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

/**
 * An extendible enumeration of order status types.
 * 
 * <ul>
 *  <li><b>DOMAIN</b> - Resolve a site based on the whole domain (e.g. request.getServerName())</li>
 *  <li><b>DOMAIN_PREFIX</b> - Resolve a site based on the first word in the domain.</li>
 * </ul>
 * 
 * For example, if the URL you wanted to resolve was
 * http://mysite.mycompany.com.
 * 
 * The {@link #getSiteIdentifierValue()} should be set as follows: 
 *    
 * to use DOMAIN resolution, set to "mysite.mycompany.com"
 * to use DOMAIN_PREFIX resolution, set to "mysite"
 * 
 * @author jfischer
 */
public class SiteResolutionType implements Serializable, BroadleafEnumerationType {

    private static final long serialVersionUID = 1L;

    private static final Map<String, SiteResolutionType> TYPES = new HashMap<String, SiteResolutionType>();


    public static final SiteResolutionType DOMAIN = new SiteResolutionType("DOMAIN", "Domain");
    public static final SiteResolutionType DOMAIN_PREFIX = new SiteResolutionType("DOMAIN_PREFIX", "Domain Prefix");

    public static SiteResolutionType getInstance(final String type) {
        return TYPES.get(type);
    }

    private String type;
    private String friendlyType;

    public SiteResolutionType() {
        //do nothing
    }

    public SiteResolutionType(final String type, final String friendlyType) {
        this.friendlyType = friendlyType;
        setType(type);
    }

    public String getType() {
        return type;
    }

    public String getFriendlyType() {
        return friendlyType;
    }

    private void setType(final String type) {
        this.type = type;
        if (!TYPES.containsKey(type)) {
            TYPES.put(type, this);
        }
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((type == null) ? 0 : type.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        SiteResolutionType other = (SiteResolutionType) obj;
        if (type == null) {
            if (other.type != null)
                return false;
        } else if (!type.equals(other.type))
            return false;
        return true;
    }

}

==> broadleaf-common-3.0.12-GA-sources.jar: org/broadleafcommerce/common/site/service/type/SiteResolutionType.java <==
/*
 * Copyright 2008-2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.broadleafcommerce.common.site.service.type;

import org.broadleafcommerce.common.BroadleafEnumerationType;

import java.io.Serializable;
import java.util.LinkedHashMap;
import java.util.Map;

/**
 * An extendible enumeration of order status types.
 * 
 * <ul>
 *  <li><b>DOMAIN</b> - Resolve a site based on the whole domain (e.g. request.getServerName())</li>
 *  <li><b>DOMAIN_PREFIX</b> - Resolve a site based on the first word in the domain.</li>
 * </ul>
 * 
 * For example, if the URL you wanted to resolve was
 * http://mysite.mycompany.com.
 * 
 * The {@link #getSiteIdentifierValue()} should be set as follows: 
 *    
 * to use DOMAIN resolution, set to "mysite.mycompany.com"
 * to use DOMAIN_PREFIX resolution, set to "mysite"
 * 
 * @author jfischer
 */
public class SiteResolutionType implements Serializable, BroadleafEnumerationType {

    private static final long serialVersionUID = 1L;

    private static final Map<String, SiteResolutionType> TYPES = new LinkedHashMap<String, SiteResolutionType>();


    public static final SiteResolutionType DOMAIN = new SiteResolutionType("DOMAIN", "Domain");
    public static final SiteResolutionType DOMAIN_PREFIX = new SiteResolutionType("DOMAIN_PREFIX", "Domain Prefix");

    public static SiteResolutionType getInstance(final String type) {
        return TYPES.get(type);
    }

    private String type;
    private String friendlyType;

    public SiteResolutionType() {
        //do nothing
    }

    public SiteResolutionType(final String type, final String friendlyType) {
        this.friendlyType = friendlyType;
        setType(type);
    }

    public String getType() {
        return type;
    }

    public String getFriendlyType() {
        return friendlyType;
    }

    private void setType(final String type) {
        this.type = type;
        if (!TYPES.containsKey(type)) {
            TYPES.put(type, this);
        }
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((type == null) ? 0 : type.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        SiteResolutionType other = (SiteResolutionType) obj;
        if (type == null) {
            if (other.type != null)
                return false;
        } else if (!type.equals(other.type))
            return false;
        return true;
    }

}
